%global codename fuerte
%global shortname bond_core

Name:		ros-%{codename}-bond-core
Version:	1.6.3
Release:	1%{?dist}
Summary:	Process bond stack for ROS
License:	BSD
URL:		http://ros.org/wiki/pluginlib
Source0:	https://code.ros.org/svn/release/download/stacks/bond_core/bond_core-%{version}/bond_core-%{version}.tar.bz2
# TODO: Unbundle SMC
Source1:	https://code.ros.org/svn/release/download/thirdparty/smc_6_0_1.tgz
BuildRequires:	ros-%{codename}-ros-devel, ros-%{codename}-ros-comm-devel
BuildRequires:	cmake, python-yaml, libuuid-devel
Provides:	ros-%{shortname} = %{version}-%{release}
Provides:	ros-bond-core = %{version}-%{release}

%description
This ROS stack enables process bonding. A bond allows two processes, A and B, 
to know when the other has terminated, either cleanly or by crashing. The 
bond remains connected until it is either broken explicitly or until a 
heartbeat times out.

%package devel
Summary:	Development files for ROS bond-core
Requires:	libuuid-devel, ros-%{codename}-ros-devel, ros-%{codename}-ros-comm-devel
Provides:	ros-%{shortname}-devel = %{version}-%{release}
Provides:	ros-bond-core-devel = %{version}-%{release}

%description devel
Development files for ROS bond-core.

%prep
%setup -q -c

%build
cd %{shortname}-%{version}
source /etc/catkin/profile.d/10.ros.all
export ROS_PACKAGE_PATH="%{_builddir}/%{name}-%{version}:$ROS_PACKAGE_PATH"
pushd smclib
mkdir build
cp %{SOURCE1} build/
make
popd
for i in bond bondcpp bondpy test_bond; do
  pushd $i
  mkdir -p build
  cd build
  %cmake -DSETUPTOOLS_DEB_LAYOUT=OFF ..
  make %{?_smp_mflags}
  popd
done

%install
cd %{shortname}-%{version}

#bond_core
mkdir -p %{buildroot}%{_datadir}/ros-stacks/bond_core/
cp -a rosdep.yaml stack.xml %{buildroot}%{_datadir}/ros-stacks/bond_core/

#bond
pushd bond
mkdir -p %{buildroot}%{python_sitelib}/
cp -a src/bond %{buildroot}%{python_sitelib}/
mkdir -p %{buildroot}%{_datadir}/ros-stacks/bond_core/bond/src
ln -s %{python_sitelib}/bond %{buildroot}%{_datadir}/ros-stacks/bond_core/bond/src/bond
cp -a *.sm *.dox *.xml msg msg_gen %{buildroot}%{_datadir}/ros-stacks/bond_core/bond/
popd

#bondcpp
pushd bondcpp
mkdir -p %{buildroot}%{_datadir}/ros-stacks/bond_core/bondcpp/lib
mkdir -p %{buildroot}%{_libdir}/
cp -a lib/* %{buildroot}%{_libdir}/
ln -s %{_libdir}/libbondcpp.so %{buildroot}%{_datadir}/ros-stacks/bond_core/bondcpp/lib/libbondcpp.so
mkdir -p %{buildroot}%{_datadir}/ros-stacks/bond_core/bondcpp/include
cp -a include/* %{buildroot}%{_datadir}/ros-stacks/bond_core/bondcpp/include/
cp -a *.dox *.xml %{buildroot}%{_datadir}/ros-stacks/bond_core/bondcpp/
popd

#bondpy
pushd bondpy
mkdir -p %{buildroot}%{_datadir}/ros-stacks/bond_core/bondpy/src
cp -a src/* %{buildroot}%{python_sitelib}/
ln -s %{python_sitelib}/BondSM_sm.py %{buildroot}%{_datadir}/ros-stacks/bond_core/bondpy/src
ln -s %{python_sitelib}/bondpy.py %{buildroot}%{_datadir}/ros-stacks/bond_core/bondpy/src
cp -a *.dox *.xml %{buildroot}%{_datadir}/ros-stacks/bond_core/bondpy/
popd

#smclib
pushd smclib
mkdir -p %{buildroot}%{_datadir}/ros-stacks/bond_core/smclib/src
cp -a src/statemap.py %{buildroot}%{python_sitelib}/
ln -s %{python_sitelib}/statemap.py %{buildroot}%{_datadir}/ros-stacks/bond_core/smclib/src/
mkdir -p %{buildroot}%{_datadir}/ros-stacks/bond_core/smclib/include
cp -a include/* %{buildroot}%{_datadir}/ros-stacks/bond_core/smclib/include/
cp -a *.dox *.xml %{buildroot}%{_datadir}/ros-stacks/bond_core/smclib/
popd

#test_bond
pushd test_bond
mkdir -p %{buildroot}%{_datadir}/ros-stacks/bond_core/test_bond/
cp -a srv scripts %{buildroot}%{_datadir}/ros-stacks/bond_core/test_bond/
cp -a *.dox *.xml %{buildroot}%{_datadir}/ros-stacks/bond_core/test_bond/
popd

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%{_datadir}/ros-stacks/bond_core/
%exclude %{_datadir}/ros-stacks/bond_core/bondcpp/include/
%exclude %{_datadir}/ros-stacks/bond_core/smclib/include/
%{python_sitelib}/bond/
%{python_sitelib}/BondSM_sm.py*
%{python_sitelib}/bondpy.py*
%{python_sitelib}/statemap.py*
%{_libdir}/libbondcpp.so

%files devel
%{_datadir}/ros-stacks/bond_core/bondcpp/include/
%{_datadir}/ros-stacks/bond_core/smclib/include/

%changelog
* Tue May 22 2012 Tom Callaway <spot@fedoraproject.org> - 1.6.3-1
- initial package
